@@ -107,6 +107,12 @@ class StringEncoder():
             for i in range(len(self.feature_indices)):
                 temp = self.encoders[i].transform(self.X[:,self.feature_indices[i]])
                 self.X = np.delete(self.X, self.feature_indices[i], axis=1)
+                
+                for k in range(len(temp[0,:])):
+                    self.X = np.insert(self.X, self.feature_indices[i]+k, temp[:,k], axis=1)
+                    
+        return np.array(self.X, dtype=np.float64)
+                
 
 class FeatureEncoder():
     def __init__(self):
